@@ -3,7 +3,7 @@ use strict; no strict 'refs';
 use warnings;
 use Carp qw/croak/; use Tie::IxHash;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 our (%object, %TYPES);
 
@@ -27,7 +27,7 @@ sub import {
 		});
 	}
 
-	for my $isa ( qw/any scalar scalarref integer float boolean ordered_hash hash array object fh/ ) {
+	for my $isa ( qw/any string scalarref integer float boolean ordered_hash hash array object fh/ ) {
 		make_keyword($called, $isa, sub {
 			my (@args) = @_;
 			my @return = (
@@ -133,12 +133,12 @@ sub required {
 
 sub any { $_[1] }
 
-sub build_scalar { "" }
+sub build_string { "" }
 
-sub scalar {
+sub string {
 	my ($value, $name) = @_;
 	if (ref $value) {
-		croak sprintf "The value passed to the %s attribute does not match the scalar type constraint.",
+		croak sprintf "The value passed to the %s attribute does not match the string type constraint.",
 			$name;
 	}
 	return $value;
@@ -252,7 +252,7 @@ YAOO - Yet Another Object Orientation
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
@@ -270,7 +270,7 @@ Version 0.02
 
 	has satellites => rw, isa(integer);
 
-	has mental => rw, isa(ordered_hash(
+	has mind => rw, isa(ordered_hash(
 		chang => 1,
 		zante => 2,
 		oistins => 3
@@ -280,7 +280,93 @@ Version 0.02
 
 	Synopsis->new( satelites => 5 );
 
-	$synopsis->mental->{oistins};
+	$synopsis->mind->{oistins};
+
+=cut
+
+=head1 keywords
+
+=cut
+
+=head2 has
+
+=cut
+
+=head2 ro
+
+=cut
+
+=head2 rw
+
+=cut
+
+=head2 isa
+
+=cut
+
+=head3 any
+
+=cut
+
+=head3 string
+
+=cut
+
+=head3 scalarref
+
+=cut
+
+=head3 integer
+
+=cut
+
+=head3 float
+
+=cut
+
+=head3 boolean
+
+=cut
+
+=head3 ordered_hash
+
+=cut
+
+=head3 hash
+
+=cut
+
+=head3 array
+
+=cut
+
+=head3 object
+
+=cut
+
+=head3 fh
+
+=cut
+
+=head2 isa
+
+=cut
+
+=head2 default
+
+=cut
+
+=head2 coerce
+
+=cut
+
+=head2 required
+
+=cut
+
+=head2 trigger
+
+=cut
 
 =head1 AUTHOR
 
